==> haskell-lpeg-1.0.4-53-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lpeg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lpeg
version:              1.0.4
visibility:           public
id:                   lpeg-1.0.4-32RX6VFyhnc42Qb6W6EWQb
key:                  lpeg-1.0.4-32RX6VFyhnc42Qb6W6EWQb
license:              MIT
copyright:
    © 2007-2019 Lua.org, PUC-Rio;
    © 2021-2023 Albert Krewinkel

maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             LPeg – Parsing Expression Grammars For Lua
description:
    This package contains the C sources of LPeg, as well
    as some tiny Haskell helper to load the package.

    <http://www.inf.puc-rio.br/~roberto/lpeg/>

category:             Foreign
abi:                  b076628402c83ef3e06a723846a0d69a
exposed:              True
exposed-modules:      Lua.LPeg
import-dirs:          /usr/lib/ghc-9.4.8/site-local/lpeg-1.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lpeg-1.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lpeg-1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lpeg
hs-libraries:         HSlpeg-1.0.4-32RX6VFyhnc42Qb6W6EWQb
depends:              base-4.17.2.1 lua-2.3.3-6P8RmztcaQADlPDXkEodsL
haddock-interfaces:   /usr/share/doc/haskell-lpeg/html/lpeg.haddock
haddock-html:         /usr/share/doc/haskell-lpeg/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lpeg-1.0.4-54-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lpeg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lpeg
version:              1.0.4
visibility:           public
id:                   lpeg-1.0.4-INfCMW1Z18vGhfAq1NLrXC
key:                  lpeg-1.0.4-INfCMW1Z18vGhfAq1NLrXC
license:              MIT
copyright:
    © 2007-2019 Lua.org, PUC-Rio;
    © 2021-2023 Albert Krewinkel

maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             LPeg – Parsing Expression Grammars For Lua
description:
    This package contains the C sources of LPeg, as well
    as some tiny Haskell helper to load the package.

    <http://www.inf.puc-rio.br/~roberto/lpeg/>

category:             Foreign
abi:                  bff748b6f750341b8446ac2241cce107
exposed:              True
exposed-modules:      Lua.LPeg
import-dirs:          /usr/lib/ghc-9.4.8/site-local/lpeg-1.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lpeg-1.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lpeg-1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lpeg
hs-libraries:         HSlpeg-1.0.4-INfCMW1Z18vGhfAq1NLrXC
depends:              base-4.17.2.1 lua-2.3.3-Dykhy43oRlQH8Cd8qVDkTO
haddock-interfaces:   /usr/share/doc/haskell-lpeg/html/lpeg.haddock
haddock-html:         /usr/share/doc/haskell-lpeg/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
